Si eres nuevo en el sector de la administración de servidores Gnu/Linux y te enfrentas a la programación de código, editar archivos de configuración, es muy útil dominar nano, un clon gratuito de pico, el cual tiene una interfaz amigable, este editor de texto se basa en los accesos rápidos por combinaciones de teclado.
Nano es un editor no modal (no se necesita ejecutar ningún comando o combinación de teclas para comenzar a editar el fichero seleccionado). Una vez iniciado muestra en la primera línea: la versión actual, el nombre del fichero que se está editando y si ha sido modificado o no; a continuación el fichero en cuestión, en la tercera línea de abajo hacia arriba los mensajes importantes y en las 2 últimas líneas atajos más comunes.
También podemos ver la versión de nano y las opciones compiladas escribiendo
nano -V
Nano usa como teclas fundamentales Ctrl(^) y Alt(M), es decir con Ctrl o Alt y otra combinación de tecla se ejecuta una acción, dentro de sus características fundamentales podemos mencionar:
- Interfaz intuitiva
- Ligera curva de aprendizaje
- Internacionalización
- Coloreado de sintaxis para C, C++, Python, Perl, Ruby, HTML, TeX otros
- Búsquedas / Reemplazo por palabras claves o expresiones regulares
- Avanzar/ Retroceder una pantalla
- Explorador de ficheros
- Edición de múltiples ficheros
- Soporte para el ratón
- Ayuda integrada al editor
Definir editor de texto por defecto
Si nuestro sistema tiene instalado varios editores de texto es interesante definir nano como el editor de texto predeterminado.
update-alternatives --config editor
Usted puede seleccionar el editor que desee con solo debe teclear el número. Por ejemplo, si quiero que vim sea el editor por defecto, solo pulso el número 2.
Lectura y edición de archivos
Crear y abrir archivos con nano es muy sencillo, simplemente escriba
nano nombrearchivo
Si está editando un archivo de configuración como /etc/fstab use el parámetro -w, para desactivar el ajuste de palabras.
nano -w /etc/fstab
Aviso: Es muy, pero que muy importante el uso de la opción -w al abrir un archivo de configuración. Si no sigue esta recomendación puede hacer que su sistema no arranque o se vuelva inestable.
Hacer un backup del archivo a editar
nano -B /etc/fstab
De esta forma al editar un archivo se crea una copia de respaldo, se puede apreciar que le agrega el ~ al nombre original del archivo, esta opción debe ser usada cada vez que editamos archivos de sistema.
Podemos verificar que se creo el respaldo del archivo con el comando:
ls -l /etc | grep fstab
Ahora si queremos tener bien organizados todos los respaldos de los archivos editados podemos invocar nano de la siguiente manera (el directorio /backup debe existir):
nano -C /backup -B /etc/fstab
y verificamos que se creo el respaldo con
ls -l /backup
Otra menera de respaldar el archivo que estamos editando es presionar Alt+b antes de iniciar la edición, este comando agrega el ~ al nobre original del archivo.
Abrir el fichero e ir la la línea 67, columna 1
nano +67,1 /etc/apache2/apache2.conf
Guardando y saliendo
Si desea guardar las modificaciones hechas, presiona Ctrl+O. Para salir de nano, presione Ctrl+X. Si has pedido salir de un fichero modificado, te preguntará si lo deseas salvar. Presione N si no quiere salvar el fichero o Y en caso que si quiera. Entonces le pedirá un nombre para el fichero, escríbalo y presione Intro.
Si por error presionas que quieres guardar el fichero, no te preocupes porque podemos cancelar presionando Ctrl+C, siempre que estés en la pantalla donde se escribe el nombre del fichero.
Seleccionar, copiar, cortar y pegar
Para seleccionar Esc+a, y con las teclas del cursor abarcamos hasta donde queremos seleccionar.
A continuación, dependiendo de lo que queramos hacer:
Para copiar lo seleccionado al buffer Esc+6
Para cortar lo seleccionado al buffer Ctrl+k
Para pegar el contenido del buffer Ctrl+u
Buscando Texto
Simplemente presione Ctrl+W e introduzca el término a buscar. Para buscar el mismo término otra vez, presione Alt+W.
Tips, comandos y atajos
Opciones de ejecución de NANO:
nano --help Muestra la ayuda
Resumen: (Opción corta y Opción larga)
+Línea: Comenzar en la línea número LÍNEA
-B --backup: Respaldar los ficheros existentes al guardar
-D --dos: Escribir el fichero en formato DOS
-M --mac: Escribir el fichero en formato Mac
-N --noconvert: No convertir los ficheros desde el formato DOS/Mac
-c --const: Mostrar constantemente la posición del cursor
-m --mouse: Habilitar ratón
-o [ dir ] –operatingdir=[ dir ]: Establecer el directorio de operación
-s [ prog ] –speller=[ prog ]: Habilitar corrector alternativo
-t --tempfile: Autosalvar al salir, no preguntar
-v --view: Modo visualización (sólo lectura)
-w --nowrap No wrapear líneas largas
Usando atajos
En los textos de ayuda de nano, la tecla Ctrl se representa por un acento circunflejo (^), por lo que Ctrl+W se muestra como ^W, y así para el resto. La tecla Alt+key se representa mediante una M (de Meta), por lo que Alt+W se muestra como M-W
(En su defecto usar Esc en lugar de Alt)
Resumen:
^G -------- (F1) Mostrar ayuda
^X -------- (F2) Salir de nano
^O -------- (F3) Guardar Archivo
^J -------- (F4) Justificar el párrafo actual
^W -------- (F6) Buscar una cadena o expresión regular
^Y -------- (F7) Moverse a la página anterior
^V -------- (F8) Moverse a la página siguiente
^K -------- (F9) Cortar la línea actual y guardarla en el cutbuffer
^U -------- (F10) Pegar el cutbuffer en la línea actual
^T -------- (F12) Invocar el corrector ortográfico (si está disponible)
^_ -------- (F13)(M-G) Ir a un número de línea en concreto
^L -------- Redibujar la pantalla actual.
^X -------- Cerrar el fichero mostrado / Salir de nano
^R -------- Insertar otro fichero en el actual
^C -------- Mostrar la posición del cursor
^M -------- Insertar un retorno de carro en la posición del cursor.
MW -------- Muestra la siguiente coincidencia
MG -------- Ir a un número de línea en concreto.
MI -------- Auto indentar habilitar/deshabilitar.
MX -------- Modo ayuda habilitar/deshabilitar.
MP -------- Modo Pico habilitar/deshabilitar.
MM -------- Soporte para ratón habilitar/deshabilitar.
MR -------- Reemplazar texto en el editor.
ME -------- Expresiones regulares habilitar/deshabilitar.
MB -------- Respaldar ficheros habilitar/deshabilitar.
MS -------- Desplazamiento suave habilitar/deshabilitar.
MH -------- Tecla 'smart home' habilitar/deshabilitar.
MY -------- Coloreado de sintaxis habilitar/deshabilitar.
MP -------- Mostrar blancos habilitar/deshabilitar.
Algunos ejemplos
^G Mostrar ayuda
MX
^C
MG
MY
Amigos, para consultas puntuales sobre este tema, pasen por esta comunidad, todos serán bienvenidos!!
_____________________________________________________________________
Si te gusto el post comenta!
Estas sin tiempo para leerlo detenidamente? Agregalo a favoritos ya!
No entendiste algo? mandame un MP que te ayudo.
Te gustan mis aportes? Seguime! no te defraudaré.
Fuentes de conocimiento:
http://linuxcomandos.blogspot.com/2008/04/comando-nano.html